# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.1.0

import enum

import winrt.system
from winrt._winrt_windows_graphics_capture import (
    Direct3D11CaptureFrame,
    Direct3D11CaptureFramePool,
    GraphicsCaptureAccess,
    GraphicsCaptureItem,
    GraphicsCapturePicker,
    GraphicsCaptureSession,
)

__all__ = [
    "GraphicsCaptureAccessKind",
    "GraphicsCaptureDirtyRegionMode",
    "Direct3D11CaptureFrame",
    "Direct3D11CaptureFramePool",
    "GraphicsCaptureAccess",
    "GraphicsCaptureItem",
    "GraphicsCapturePicker",
    "GraphicsCaptureSession",
]

class GraphicsCaptureAccessKind(enum.IntEnum):
    BORDERLESS = 0
    PROGRAMMATIC = 1

class GraphicsCaptureDirtyRegionMode(enum.IntEnum):
    REPORT_ONLY = 0
    REPORT_AND_RENDER = 1

